@@ -125,7 +125,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: ncat_listen.c 36488 2016-12-14 00:12:23Z fyodor $ */
+/* $Id: ncat_listen.c 36699 2017-04-04 16:27:59Z dmiller $ */
 
 #include "ncat.h"
 
@@ -344,7 +344,11 @@ static int ncat_listen_stream(int proto)
         if (o.idletimeout > 0)
             ms_to_timeval(tvp, o.idletimeout);
 
-        fds_ready = fselect(client_fdlist.fdmax + 1, &readfds, &writefds, NULL, tvp);
+        /* The idle timer should only be running when there are active connections */
+        if (get_conn_count())
+            fds_ready = fselect(client_fdlist.fdmax + 1, &readfds, &writefds, NULL, tvp);
+        else
+            fds_ready = fselect(client_fdlist.fdmax + 1, &readfds, &writefds, NULL, NULL);
 
         if (o.debug > 1)
             logdebug("select returned %d fds ready\n", fds_ready);
@@ -628,6 +632,9 @@ int read_socket(int recv_fd)
     char buf[DEFAULT_TCP_BUF_LEN];
     struct fdinfo *fdn;
     int nbytes, pending;
+#ifdef HAVE_OPENSSL
+    int err = SSL_ERROR_NONE;
+#endif
 
     fdn = get_fdinfo(&client_fdlist, recv_fd);
     ncat_assert(fdn != NULL);
@@ -637,11 +644,28 @@ int read_socket(int recv_fd)
         int n;
 
         n = ncat_recv(fdn, buf, sizeof(buf), &pending);
-        if (n <= 0) {
+#ifdef HAVE_OPENSSL
+        /* SSL_read returns <0 in some cases like renegotiation. In these
+         * cases, SSL_get_error gives SSL_ERROR_WANT_{READ,WRITE}, and we
+         * should try the SSL_read again. */
+        if (n < 0 && o.ssl && fdn->ssl) {
+            err = SSL_get_error(fdn->ssl, n);
+            if (err == SSL_ERROR_WANT_READ || err == SSL_ERROR_WANT_WRITE) {
+                pending = 1;
+            }
+        }
+#endif
+        /* If return value is 0, it's a clean shutdown from the other side, SSL
+         * or plain. If <0, it's an error. If pending, the error may be
+         * recoverable with a second SSL_read, so don't shut down yet. */
+        if (n <= 0 && !pending) {
             if (o.debug)
-                logdebug("Closing connection.\n");
+                logdebug("Closing fd %d.\n", recv_fd);
 #ifdef HAVE_OPENSSL
             if (o.ssl && fdn->ssl) {
+                if (n < 0 && o.debug) {
+                    logdebug("SSL error on %d: %s\n", recv_fd, ERR_error_string(err, NULL));;
+                }
                 if (nbytes == 0)
                     SSL_shutdown(fdn->ssl);
                 SSL_free(fdn->ssl);
@@ -659,9 +683,10 @@ int read_socket(int recv_fd)
 
             return n;
         }
-
-        Write(STDOUT_FILENO, buf, n);
-        nbytes += n;
+        else if (n > 0) {
+            Write(STDOUT_FILENO, buf, n);
+            nbytes += n;
+        }
     } while (pending);
 
     return nbytes;
@@ -785,7 +810,11 @@ static int ncat_listen_dgram(int proto)
             if (o.idletimeout > 0)
                 ms_to_timeval(tvp, o.idletimeout);
 
-            fds_ready = fselect(listen_fdlist.fdmax + 1, &fds, NULL, NULL, tvp);
+            /* The idle timer should only be running when there are active connections */
+            if (get_conn_count())
+                fds_ready = fselect(listen_fdlist.fdmax + 1, &fds, NULL, NULL, tvp);
+            else
+                fds_ready = fselect(listen_fdlist.fdmax + 1, &fds, NULL, NULL, NULL);
 
             if (o.debug > 1)
                 logdebug("select returned %d fds ready\n", fds_ready);
