@@ -6,18 +6,18 @@
  *                                                                         *
  ***********************IMPORTANT NMAP LICENSE TERMS************************
  *                                                                         *
- * The Nmap Security Scanner is (C) 1996-2016 Insecure.Com LLC. Nmap is    *
- * also a registered trademark of Insecure.Com LLC.  This program is free  *
- * software; you may redistribute and/or modify it under the terms of the  *
- * GNU General Public License as published by the Free Software            *
- * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
- * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
- * modify, and redistribute this software under certain conditions.  If    *
- * you wish to embed Nmap technology into proprietary software, we sell    *
- * alternative licenses (contact sales@nmap.com).  Dozens of software      *
- * vendors already license Nmap technology such as host discovery, port    *
- * scanning, OS detection, version detection, and the Nmap Scripting       *
- * Engine.                                                                 *
+ * The Nmap Security Scanner is (C) 1996-2016 Insecure.Com LLC ("The Nmap  *
+ * Project"). Nmap is also a registered trademark of the Nmap Project.     *
+ * This program is free software; you may redistribute and/or modify it    *
+ * under the terms of the GNU General Public License as published by the   *
+ * Free Software Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE   *
+ * CLARIFICATIONS AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your   *
+ * right to use, modify, and redistribute this software under certain      *
+ * conditions.  If you wish to embed Nmap technology into proprietary      *
+ * software, we sell alternative licenses (contact sales@nmap.com).        *
+ * Dozens of software vendors already license Nmap technology such as      *
+ * host discovery, port scanning, OS detection, version detection, and     *
+ * the Nmap Scripting Engine.                                              *
  *                                                                         *
  * Note that the GPL places important restrictions on "derivative works",  *
  * yet it does not provide a detailed definition of that term.  To avoid   *
@@ -59,11 +59,18 @@
  * particularly including the GPL Section 3 requirements of providing      *
  * source code and allowing free redistribution of the work as a whole.    *
  *                                                                         *
- * As another special exception to the GPL terms, Insecure.Com LLC grants  *
+ * As another special exception to the GPL terms, the Nmap Project grants  *
  * permission to link the code of this program with any version of the     *
  * OpenSSL library which is distributed under a license identical to that  *
  * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
  * linked combinations including the two.                                  *
+ *                                                                         * 
+ * The Nmap Project has permission to redistribute Npcap, a packet         *
+ * capturing driver and library for the Microsoft Windows platform.        *
+ * Npcap is a separate work with it's own license rather than this Nmap    *
+ * license.  Since the Npcap license does not permit redistribution        *
+ * without special permission, our Nmap Windows binary packages which      *
+ * contain Npcap may not be redistributed without special permission.      *
  *                                                                         *
  * Any redistribution of Covered Software, including any derived works,    *
  * must obey and carry forward all of the terms of this license, including *
@@ -104,12 +111,12 @@
  * to the dev@nmap.org mailing list for possible incorporation into the    *
  * main distribution.  By sending these changes to Fyodor or one of the    *
  * Insecure.Org development mailing lists, or checking them into the Nmap  *
- * source code repository, it is understood (unless you specify otherwise) *
- * that you are offering the Nmap Project (Insecure.Com LLC) the           *
- * unlimited, non-exclusive right to reuse, modify, and relicense the      *
- * code.  Nmap will always be available Open Source, but this is important *
- * because the inability to relicense code has caused devastating problems *
- * for other Free Software projects (such as KDE and NASM).  We also       *
+ * source code repository, it is understood (unless you specify            *
+ * otherwise) that you are offering the Nmap Project the unlimited,        *
+ * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
+ * will always be available Open Source, but this is important because     *
+ * the inability to relicense code has caused devastating problems for     *
+ * other Free Software projects (such as KDE and NASM).  We also           *
  * occasionally relicense the code to third parties as discussed above.    *
  * If you wish to specify special license conditions of your               *
  * contributions, just say so when you send them.                          *
@@ -122,7 +129,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: nmap.h 36373 2016-10-18 03:06:07Z dmiller $ */
+/* $Id: nmap.h 36785 2017-06-07 02:33:14Z dmiller $ */
 
 #ifndef NMAP_H
 #define NMAP_H
@@ -159,16 +166,6 @@
 #include <sys/param.h> /* Defines MAXHOSTNAMELEN on BSD*/
 #endif
 
-#if HAVE_RPC_TYPES_H
-/* Is this needed any more since rpcgrind was converted to NSE? */
-#include <rpc/types.h>
-#endif
-
-/* For systems without SCTP in netinet/in.h, such as MacOS X */
-#ifndef IPPROTO_SCTP
-#define IPPROTO_SCTP 132
-#endif
-
 /* Keep assert() defined for security reasons */
 #undef NDEBUG
 
@@ -193,13 +190,13 @@
 #ifndef NMAP_VERSION
 /* Edit this definition only within the quotes, because it is read from this
    file by the makefiles. */
-#define NMAP_VERSION "7.31"
-#define NMAP_NUM_VERSION "7.0.31.0"
+#define NMAP_VERSION "7.50"
+#define NMAP_NUM_VERSION "7.0.50.0"
 #endif
 /* The version number of updates retrieved by the nmap-update
    program. It can be different (but should always be the same or
    earlier) than NMAP_VERSION. */
-#define NMAP_UPDATE_CHANNEL "7.30"
+#define NMAP_UPDATE_CHANNEL "7.40"
 
 #define NMAP_XMLOUTPUTVERSION "1.04"
 
@@ -230,8 +227,6 @@
 
 #define MAX_DECOYS 128 /* How many decoys are allowed? */
 
-#define MAXFALLBACKS 20 /* How many comma separated fallbacks are allowed in the service-probes file? */
-
 /* TCP Options for TCP SYN probes: MSS 1460 */
 #define TCP_SYN_PROBE_OPTIONS "\x02\x04\x05\xb4"
 #define TCP_SYN_PROBE_OPTIONS_LEN (sizeof(TCP_SYN_PROBE_OPTIONS)-1)
@@ -334,61 +329,12 @@
 #  define recvfrom6_t int
 #endif
 
-/***********************STRUCTURES**********************************/
-
-/* The various kinds of port/protocol scans we can have
- * Each element is to point to an array of port/protocol numbers
- */
-struct scan_lists {
-        /* The "synprobes" are also used when doing a connect() ping */
-        unsigned short *syn_ping_ports;
-        unsigned short *ack_ping_ports;
-        unsigned short *udp_ping_ports;
-        unsigned short *sctp_ping_ports;
-        unsigned short *proto_ping_ports;
-        int syn_ping_count;
-        int ack_ping_count;
-        int udp_ping_count;
-        int sctp_ping_count;
-        int proto_ping_count;
-        //the above fields are only used for host discovery
-        //the fields below are only used for port scanning
-        unsigned short *tcp_ports;
-        int tcp_count;
-        unsigned short *udp_ports;
-        int udp_count;
-        unsigned short *sctp_ports;
-        int sctp_count;
-        unsigned short *prots;
-        int prot_count;
-};
-
-typedef enum { STYPE_UNKNOWN, HOST_DISCOVERY, ACK_SCAN, SYN_SCAN, FIN_SCAN, XMAS_SCAN, UDP_SCAN, CONNECT_SCAN, NULL_SCAN, WINDOW_SCAN, SCTP_INIT_SCAN, SCTP_COOKIE_ECHO_SCAN, MAIMON_SCAN, IPPROT_SCAN, PING_SCAN, PING_SCAN_ARP, IDLE_SCAN, BOUNCE_SCAN, SERVICE_SCAN, OS_SCAN, SCRIPT_PRE_SCAN, SCRIPT_SCAN, SCRIPT_POST_SCAN, TRACEROUTE, PING_SCAN_ND }stype;
-
 /***********************PROTOTYPES**********************************/
 
-/* print Interactive usage information */
-void printinteractiveusage();
-
-/* port manipulators */
-void getpts(const char *expr, struct scan_lists * ports); /* someone stole the name getports()! */
-void getpts_simple(const char *origexpr, int range_type,
-                   unsigned short **list, int *count);
-void removepts(const char *expr, struct scan_lists * ports);
-void free_scan_lists(struct scan_lists *ports);
-
 /* Renamed main so that interactive mode could preprocess when necessary */
 int nmap_main(int argc, char *argv[]);
 
-void nmap_free_mem();
-
-/* general helper functions */
-const char *statenum2str(int state);
-const char *scantype2str(stype scantype);
-void reaper(int signo);
-
 int nmap_fetchfile(char *filename_returned, int bufferlen, const char *file);
-int nmap_fileexistsandisreadable(const char* pathname);
 int gather_logfile_resumption_state(char *fname, int *myargc, char ***myargv);
 
 #endif /* NMAP_H */
