@@ -132,7 +132,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: output.cc 36488 2016-12-14 00:12:23Z fyodor $ */
+/* $Id: output.cc 36751 2017-05-02 20:36:08Z dmiller $ */
 
 #include "nmap.h"
 #include "output.h"
@@ -144,7 +144,9 @@
 #include "portreasons.h"
 #include "protocols.h"
 #include "FingerPrintResults.h"
+#include "tcpip.h"
 #include "Target.h"
+#include "nmap_error.h"
 #include "utils.h"
 #include "xml.h"
 #include "nbase.h"
@@ -662,12 +664,7 @@ void printportoutput(Target *currenths, PortList *plist) {
     prevstate = istate;
   }
 
-  if (prevstate != PORT_UNKNOWN) {
-    log_write(LOG_PLAIN, "\n");
-    if (o.defeat_rst_ratelimit) {
-      log_write(LOG_PLAIN, "Some closed ports may be reported as filtered due to --defeat-rst-ratelimit\n");
-    }
-  }
+  log_write(LOG_PLAIN, "\n");
 
   if (o.reason)
     print_state_summary(plist, STATE_REASON_FULL);
@@ -877,6 +874,10 @@ void printportoutput(Target *currenths, PortList *plist) {
   xml_end_tag(); /* ports */
   xml_newline();
 
+  if (o.defeat_rst_ratelimit && o.TCPScan() && plist->getStateCounts(PORT_FILTERED) > 0) {
+    log_write(LOG_PLAIN, "Some closed ports may be reported as filtered due to --defeat-rst-ratelimit\n");
+  }
+
   // Now we write the table for the user
   log_write(LOG_PLAIN, "%s", Tbl->printableTable(NULL));
   delete Tbl;
